@@ -1,6 +1,4 @@
-import json
-import math
-import os,sys
+import json,os
 
 basic  = {"data": [], "Alerts": 0, "Authors": []}
 home = os.path.join(os.path.dirname(__file__))+ "/"
@@ -11,8 +9,6 @@ try:
 except:
     with open(home + "data.json","a") as f:
         json.dump(basic,f)
-    with open(home + "data2.json","a") as f:
-        json.dump(basic,f)
     datas = basic
 
 basicInfo = {"name": "","to": "","data": {}}
@@ -32,38 +28,37 @@ def UpdateValue():
 def is_non_zero_file(fpath):  
     return os.path.isfile(fpath) and os.path.getsize(fpath) > 0
 
-def getFrom(reader,author,id,ValueId):
+def getFrom(id,ValueId):
     global datas
     UpdateValue()
     return datas["data"][id]["data"][ValueId]
 def add(x, y):
     return x + y
-def Alert():
-    datas["Alerts"] = add(datas["Alerts"],1)
-    UpdateValue()
 
-def UpdateData(author,reader,ValueId,Value,id=-1):
+def UpdateData(author,reader,ValueId,Value,id=None):
     global datas
-    if id == -1:
+    if id == None:
+        UpdateValue()
         datas["data"].append(basicInfo)
         id = len(datas["data"])-1
+        if(author in datas["Authors"]):
+            id = IdFromAuthor(author)
         datas["data"][id]["name"] = author
         datas["data"][id]["to"] = reader
         datas["data"][id]["data"][ValueId] = Value
-        with open(home + "data.json","w+") as f:
-            f.truncate(0)
-            f.seek(0)
-            datas["Authors"].append(author)
-            Alert()
+        datas["Authors"].append(author)
+        with open(home + "data.json","w") as f:
+            f.seek(0)  # rewind
             json.dump(datas,f)
+            f.truncate()
         return id
-    if id == IdFromAuthor(author):
-        datas["data"][id]["name"] = author
-        datas["data"][id]["to"] = reader
-        datas["data"][id]["data"][ValueId] = Value
-        with open(home + "data.json","w+") as f:
+    if id >=0:
+        UpdateValue()
+        with open(home + "data.json","w") as f:
+            f.seek(0)  # rewind
             f.truncate(0)
-            f.seek(0)
-            Alert()
+            datas["data"][id]["name"] = author
+            datas["data"][id]["to"] = reader
+            datas["data"][id]["data"][ValueId] = Value
             json.dump(datas,f)
         return
\ No newline at end of file
